==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "Organization", "index.html#Organization", null ],
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__CUDA__Extensions.html#gaa4993365b79eeba3bc7b595a246ce91c",
"group__API__Codelet__And__Tasks.html#gaac492d7132cc930b8483b571d0dd4333",
"group__API__Data__Interfaces.html#ga057157e8f437d111d74b7167386f9e9a",
"group__API__Data__Interfaces.html#gaa23416a6d049b276fe57b19e069b68b3",
"group__API__Data__Management.html#ga7badde35fa2205201fad73fd851133fa",
"group__API__Data__Partition.html#gab931b6026c134fa98bb72fb2f7c0c67f",
"group__API__HeteroPrio.html#gga4e0acb1eccee22933b75f4976966ed33ac6732370a24b4da69f3e88eaf1534ef8",
"group__API__Interop__Support.html#ga05da3da2a43ade7e1ebb61662bdf1e21",
"group__API__MPI__Support.html#ga70687c70156fa88dcaf7be605566f42e",
"group__API__Modularized__Scheduler.html#af659dfd36be42caa6e0b688d6a9c8888",
"group__API__OpenCL__Extensions.html#structstarpu__opencl__program",
"group__API__Out__Of__Core.html#aa9c45355d7c609a9deccd366fab8ab5b",
"group__API__Perf__Steering.html#ga55d1531a49828cbc31306d79df55b363",
"group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a",
"group__API__SC__Hypervisor.html#gac3b55f616c270eb90c0103d6f062d384",
"group__API__Scheduling__Contexts.html#ga6ae38faa632f496d81f0cf3b0cec5c77",
"group__API__Task__Bundles.html#gacb73894185b73d1da811a88b084ba151",
"group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc",
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html#a8c1d8a57d6e8012b7d71608849dbcdbe",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html#a30b9638e30289370fe5796144ec30f0e",
"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html#afaaeee03dc78bbdb24ef7f9faf9dd48f",
"interfacestarpu__mod_1_1starpu__init.html#a84a478b7eb0c25f7276515c5ab75f633",
"starpu__config_8h.html#ab6191641d4441cad9473237b72c1e25b",
"starpufft_8h.html#a8d10d956e314772a339b80976afd11dd"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga2c02b8445a0b90109ff9943ec8e93b49",
"group__API__Data__Interfaces.html#ga08bed7d1e9b7cb2b2b76932eb9c33353",
"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a",
"group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5",
"group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70",
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27",
"group__API__Perf__Monitoring.html#ggab66267d03f0557b14cc3ec0c24c01ebaa99c605ec09b32e1cce0ba51df5081f1d",
"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21",
"group__API__Standard__Memory__Library.html#ga864a3b576a56d686010cfd6c9d5ef14b",
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html",
"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html",
"starpu__bound_8h.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
